#
# spec file for package meson
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name   mesonbuild
Name:           meson
Version:        0.33.0
Release:        1.2
Summary:        High productivity build system
License:        Apache-2.0
Group:          Development/Tools/Building
Url:            http://mesonbuild.com/
Source:         https://github.com/%{_name}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/%{_name}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
# PATCH-FIX-UPSTREAM meson-633.patch dimstar@opensuse.org -- Handle both DT_RPATH as well as DT_RUNPATH when fixing rpath settings
Patch0:         meson-633.patch
# PATCH-FIX-UPSTREAM meson-typelib-install.patch dimstar@opensuse.org -- Correct install path for gi typelibs, taken from upstream git
Patch1:         meson-typelib-install.patch
BuildRequires:  bison
BuildRequires:  boost-devel
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gcc-obj-c++
BuildRequires:  gcc-objc
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  gtk-doc
BuildRequires:  java-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  mono-core
BuildRequires:  mono-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  python3 >= 3.4
BuildRequires:  python3-devel
BuildRequires:  python3-gobject
BuildRequires:  python3-setuptools
BuildRequires:  vala
BuildRequires:  wxWidgets-devel >= 3.0.0
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(zlib)
Requires:       ninja
# meson-gui was last used in openSUSE Leap 42.1.
Provides:       %{name}-gui = %{version}
Obsoletes:      %{name}-gui < %{version}
BuildArch:      noarch

%description
Meson is a build system designed to optimise programmer
productivity. It aims to do this by providing simple,
out-of-the-box support for modern software development tools and
practices, such as unit tests, coverage reports, Valgrind, CCache
and the like.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

# Lack of gtest, gmock, gnustep.
rm -rf "test cases/frameworks/2 gtest" \
  "test cases/frameworks/3 gmock/"     \
  "test cases/objc/2 nsstring"

%build
python3 setup.py build

%install
python3 setup.py install \
  --root=%{buildroot} --prefix=%{_prefix}

for file in %{buildroot}%{_bindir}/*.py; do
    mv -fv "$file" "${file%.py}"
done
install -Dm 0644 data/macros.%{name} \
  %{buildroot}%{_rpmconfigdir}/macros.d/macros.%{name}

%check
export MESON_PRINT_TEST_OUTPUT=1
python3 run_tests.py

%files
%defattr(-,root,root)
%doc authors.txt contributing.txt COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}conf
%{_bindir}/%{name}introspect
%{_bindir}/wraptool
%{python3_sitelib}/%{_name}/
%{python3_sitelib}/%{name}-*
%{_rpmconfigdir}/macros.d/macros.%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}conf.1%{?ext_man}
%{_mandir}/man1/%{name}introspect.1%{?ext_man}
%{_mandir}/man1/wraptool.1%{?ext_man}

%changelog
* Wed Aug 17 2016 dimstar@opensuse.org
- Update to version 0.33.0:
  + Correctly install .typelib files to libdir.
  + Add option for as-needed link option.
  + Print the CFLAGS/LDFLAGS/etc inherited from the environment.
  + Only append compile flags to the link flags when appropriate.
- Add meson-633.patch: Handle both DT_RPATH as well as DT_RUNPATH
  when fixing rpath settings (gh#mesonbuild/meson#663).
- Add meson-typelib-install.patch: Fix installation path for
  gpobject introspection typelib files.
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 0.32.0:
  * No changelog available.
- Remove meson-gui package: GUI was removed upstream.
* Mon May  9 2016 jengelh@inai.de
- Avoid unnecessary bashism in %%install script (run with /bin/sh)
* Sat May  7 2016 sor.alexei@meowr.ru
- Update to version 0.31.0.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.29.0.
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 0.28.0.
* Fri Dec  4 2015 sor.alexei@meowr.ru
- Update to 0.27.0.
* Sun Sep 13 2015 sor.alexei@meowr.ru
- Update to 0.26.0.
- Use signed tarball.
* Sun Jul 12 2015 sor.alexei@meowr.ru
- Initial package based on the work of Igor Gnatenko.
